aboutsummaryrefslogtreecommitdiffstats
path: root/drivers/gdisp/Nokia6610
diff options
context:
space:
mode:
Diffstat (limited to 'drivers/gdisp/Nokia6610')
-rw-r--r--drivers/gdisp/Nokia6610/gdisp_lld.c10
-rw-r--r--drivers/gdisp/Nokia6610/gdisp_lld_board_example.h4
-rw-r--r--drivers/gdisp/Nokia6610/gdisp_lld_board_olimexsam7ex256.h4
3 files changed, 9 insertions, 9 deletions
diff --git a/drivers/gdisp/Nokia6610/gdisp_lld.c b/drivers/gdisp/Nokia6610/gdisp_lld.c
index 97fc34b6..04a39545 100644
--- a/drivers/gdisp/Nokia6610/gdisp_lld.c
+++ b/drivers/gdisp/Nokia6610/gdisp_lld.c
@@ -125,7 +125,7 @@ bool_t GDISP_LLD(init)(void) {
delayms(20);
// Get the bus for the following initialisation commands
- get_bus();
+ acquire_bus();
#if defined(GDISP_USE_GE8)
write_cmd3(DISCTL, 0x00, 0x20, 0x00); // Display control
@@ -245,7 +245,7 @@ void GDISP_LLD(drawpixel)(coord_t x, coord_t y, color_t color) {
#if GDISP_NEED_VALIDATION || GDISP_NEED_CLIP
if (x < GDISP.clipx0 || y < GDISP.clipy0 || x >= GDISP.clipx1 || y >= GDISP.clipy1) return;
#endif
- get_bus();
+ acquire_bus();
setviewport(x, y, 1, 1);
write_cmd3(RAMWR, 0, (color>>8) & 0x0F, color & 0xFF);
release_bus();
@@ -277,7 +277,7 @@ void GDISP_LLD(drawpixel)(coord_t x, coord_t y, color_t color) {
tuples = (cx*cy+1)/2; // With an odd sized area we over-print by one pixel.
// This extra pixel is ignored by the controller.
- get_bus();
+ acquire_bus();
setviewport(x, y, cx, cy);
write_cmd(RAMWR);
for(i=0; i < tuples; i++)
@@ -319,7 +319,7 @@ void GDISP_LLD(drawpixel)(coord_t x, coord_t y, color_t color) {
endx = srcx + cx;
endy = y + cy;
- get_bus();
+ acquire_bus();
setviewport(x, y, cx, cy);
write_cmd(RAMWR);
@@ -537,7 +537,7 @@ void GDISP_LLD(drawpixel)(coord_t x, coord_t y, color_t color) {
return;
case GDISP_CONTROL_CONTRAST:
if ((unsigned)value > 100) value = (void *)100;
- get_bus();
+ acquire_bus();
#if defined(GDISP_USE_GE8)
write_cmd2(VOLCTR, (unsigned)value, 0x03);
#elif defined(GDISP_USE_GE12)
diff --git a/drivers/gdisp/Nokia6610/gdisp_lld_board_olimexsam7ex256.h b/drivers/gdisp/Nokia6610/gdisp_lld_board_olimexsam7ex256.h
index 7b2aed43..3d1e6ceb 100644
--- a/drivers/gdisp/Nokia6610/gdisp_lld_board_olimexsam7ex256.h
+++ b/drivers/gdisp/Nokia6610/gdisp_lld_board_olimexsam7ex256.h
@@ -137,8 +137,8 @@ static __inline void set_backlight(uint8_t percent) {
*
* @notapi
*/
-static __inline void get_bus(void) {
- // Nothing to do for this board as the LCD is the only device on the SPI port
+static __inline void acquire_bus(void) {
+ /* Nothing to do for this board as the LCD is the only device on the SPI port */
}
/**
diff --git a/drivers/gdisp/Nokia6610/gdisp_lld_board_example.h b/drivers/gdisp/Nokia6610/gdisp_lld_board_example.h
index 8b315935..de8eb6ce 100644
--- a/drivers/gdisp/Nokia6610/gdisp_lld_board_example.h
+++ b/drivers/gdisp/Nokia6610/gdisp_lld_board_example.h
@@ -76,8 +76,8 @@ static __inline void set_backlight(uint8_t percent) {
*
* @notapi
*/
-static __inline void get_bus(void) {
-#error "gdispNokia6610: You must supply a definition for get_bus for your board"
+static __inline void acquire_bus(void) {
+#error "gdispNokia6610: You must supply a definition for acquire_bus for your board"
}
/**